==> mandelbulber2_2.09.3.orig.tar.gz: mandelbulber2-2.09-3/src/random.cpp <==
/**
 * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
 *                                             ,B" ]L,,p%%%,,,§;, "K
 * Copyright (C) 2014-15 Krzysztof Marczak     §R-==%w["'~5]m%=L.=~5N
 *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
 * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
 *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
 * Mandelbulber is free software:     §R.ß~-Q/M=,=5"v"]=Qf,'§"M= =,M.§ Rz]M"Kw
 * you can redistribute it and/or     §w "xDY.J ' -"m=====WeC=\ ""%""y=%"]"" §
 * modify it under the terms of the    "§M=M =D=4"N #"%==A%p M§ M6  R' #"=~.4M
 * GNU General Public License as        §W =, ][T"]C  §  § '§ e===~ U  !§[Z ]N
 * published by the                    4M",,Jm=,"=e~  §  §  j]]""N  BmM"py=ßM
 * Free Software Foundation,          ]§ T,M=& 'YmMMpM9MMM%=w=,,=MT]M m§;'§,
 * either version 3 of the License,    TWw [.j"5=~N[=§%=%W,T ]R,"=="Y[LFT ]N
 * or (at your option)                   TW=,-#"%=;[  =Q:["V""  ],,M.m == ]N
 * any later version.                      J§"mr"] ,=,," =="""J]= M"M"]==ß"
 *                                          §= "=C=4 §"eM "=B:m|4"]#F,§~
 * Mandelbulber is distributed in            "9w=,,]w em%wJ '"~" ,=,,ß"
 * the hope that it will be useful,                 . "K=  ,=RMMMßM"""
 * but WITHOUT ANY WARRANTY;                            .'''
 * without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Mandelbulber. If not, see <http://www.gnu.org/licenses/>.
 *
 * ###########################################################################
 *
 * Authors: Sebastian Jennen (jenzebas@gmail.com)
 *
 * cRandom class - crossplatform deterministic random generator based on GSL library
 */

#include "random.hpp"

cRandom::cRandom()
{
	gBaseRand = gsl_rng_alloc(gsl_rng_mt19937);
}

cRandom::~cRandom()
{
	gsl_rng_free(gBaseRand);
}

void cRandom::Initialize(int seed)
{
	gsl_rng_set(gBaseRand, seed);
}

int cRandom::Random(unsigned long max)
{
	return gsl_rng_uniform_int(gBaseRand, max + 1);
}

double cRandom::Random(double min, double max, double resolution)
{
	double range = max - min;
	unsigned long n = round(range / resolution);
	return min + resolution * Random(n);
}

// generates random number with more precision
// works with range / resolution < unsigned long long MAX
double cRandom::DoubleRandom(double min, double max)
{
	double range = max - min;
	double random = gsl_rng_uniform(gBaseRand);
	return min + random * range;
}

==> mandelbulber2_2.10.orig.tar.gz: mandelbulber2-2.10/src/random.cpp <==
/**
 * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
 *                                             ,B" ]L,,p%%%,,,§;, "K
 * Copyright (C) 2014-17 Mandelbulber Team     §R-==%w["'~5]m%=L.=~5N
 *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
 * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
 *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
 * Mandelbulber is free software:     §R.ß~-Q/M=,=5"v"]=Qf,'§"M= =,M.§ Rz]M"Kw
 * you can redistribute it and/or     §w "xDY.J ' -"m=====WeC=\ ""%""y=%"]"" §
 * modify it under the terms of the    "§M=M =D=4"N #"%==A%p M§ M6  R' #"=~.4M
 * GNU General Public License as        §W =, ][T"]C  §  § '§ e===~ U  !§[Z ]N
 * published by the                    4M",,Jm=,"=e~  §  §  j]]""N  BmM"py=ßM
 * Free Software Foundation,          ]§ T,M=& 'YmMMpM9MMM%=w=,,=MT]M m§;'§,
 * either version 3 of the License,    TWw [.j"5=~N[=§%=%W,T ]R,"=="Y[LFT ]N
 * or (at your option)                   TW=,-#"%=;[  =Q:["V""  ],,M.m == ]N
 * any later version.                      J§"mr"] ,=,," =="""J]= M"M"]==ß"
 *                                          §= "=C=4 §"eM "=B:m|4"]#F,§~
 * Mandelbulber is distributed in            "9w=,,]w em%wJ '"~" ,=,,ß"
 * the hope that it will be useful,                 . "K=  ,=RMMMßM"""
 * but WITHOUT ANY WARRANTY;                            .'''
 * without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Mandelbulber. If not, see <http://www.gnu.org/licenses/>.
 *
 * ###########################################################################
 *
 * Authors: Sebastian Jennen (jenzebas@gmail.com)
 *
 * cRandom class - crossplatform deterministic random generator based on GSL library
 */

#include "random.hpp"

cRandom::cRandom()
{
	gBaseRand = gsl_rng_alloc(gsl_rng_mt19937);
}

cRandom::~cRandom()
{
	gsl_rng_free(gBaseRand);
}

void cRandom::Initialize(int seed) const
{
	gsl_rng_set(gBaseRand, seed);
}

int cRandom::Random(unsigned long max) const
{
	return gsl_rng_uniform_int(gBaseRand, max + 1);
}

double cRandom::Random(double min, double max, double resolution) const
{
	double range = max - min;
	unsigned long n = static_cast<unsigned long>(round(range / resolution));
	return min + resolution * Random(n);
}

// generates random number with more precision
// works with range / resolution < unsigned long long MAX
double cRandom::DoubleRandom(double min, double max) const
{
	double range = max - min;
	double random = gsl_rng_uniform(gBaseRand);
	return min + random * range;
}
